zms.IZMSCatalogConnector.IZMSCatalogConnector

Package zms :: Module IZMSCatalogConnector :: Class IZMSCatalogConnector |
[frames] | no frames]

# Class IZMSCatalogConnector

    zope.interface.Interface --+
                               |
                              IZMSCatalogConnector

Instance Methods
`list` |
search(self, qs, order=None) Search. |
`str` |
reindex_all(self) Reindex. |
`str` |
reindex_node(self, node) Reindex single node. |
`list` |
get_sitemap(self) Returns sitemap. |

Method Details

### search(self, qs, order=None) |
Search. @param qs query-string @param order Returns: `list`